# TinyCircuits Wireling Light Sensor Python AST1012

This repository holds a python example meant for using a TinyCircuits Ambient Light Sensor Wireling with a Raspberry Pi and Wireling Pi Hat.

To install, use 

```
pip3 tinycircuits-tsl2572
```

or if your default is Python 3:

```
pip install tinycircuits-tsl2572
```

Software written by: [TinyCircuits](https://tinycircuits.com/) for use with TinyCircuits hardware 

